lightningcss_feature_names_to_mask

Function lightningcss_feature_names_to_mask 

pub fn lightningcss_feature_names_to_mask(
    names: &[impl Deref<Target = str>],
) -> Result<u32>
Convert dash-case feature name strings to a lightningcss Features bitmask.

Uses the canonical Features constants from the lightningcss crate. Composite names (selectors, media-queries, colors) OR together the bits of their constituent individual features.

Feature names must match: packages/next/src/server/config-shared.ts (LIGHTNINGCSS_FEATURE_NAMES)