pub fn get_edge_chunking_context_with_client_assets(
options: EdgeChunkingContextOptions,
) -> Vc<Box<dyn ChunkingContext>>Expand description
Like get_edge_chunking_context but all assets are emitted as client assets (so /_next)
pub fn get_edge_chunking_context_with_client_assets(
options: EdgeChunkingContextOptions,
) -> Vc<Box<dyn ChunkingContext>>Like get_edge_chunking_context but all assets are emitted as client assets (so /_next)